from distutils.core import setup

setup(

        name        = 'nesteri',

        version     = '1.4.1',

        py_modules  = ['nesteri'],

        author      = 'anakorellana',

        author_email= 'anakorellana@gmail.com',

        url         = 'http://www.headfirstlabs.com',

        description = 'A simple printer of nested lists',)
